Files
TheRock/debug-tools/rocgdb/source/gdb/testsuite/gdb.rocm/lane-pc-vega20.cpp
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

119 lines
3.9 KiB
C++

/* Copyright (C) 2021-2024 Free Software Foundation, Inc.
Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights reserved.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>. */
#include <cstring>
#include <hip/hip_runtime.h>
#include <iostream>
#include <stdio.h>
#include <stdlib.h>
#define CHECK(cmd) \
{ \
hipError_t error = cmd; \
if (error != hipSuccess) \
{ \
std::cerr << "error: '" << hipGetErrorString (error) << "'(" << error \
<< ") at " << __FILE__ << ":" << __LINE__ << std::endl; \
exit (EXIT_FAILURE); \
} \
}
static constexpr size_t LANE_NUM = 32;
static constexpr char ARCH[] = "gfx906";
int
main (int argc, char *argv[])
{
int device_id, device_count;
CHECK (hipGetDeviceCount (&device_count));
for (device_id = 0; device_id < device_count; ++device_id)
{
hipDeviceProp_t properties;
CHECK (hipGetDeviceProperties (&properties, device_id));
if (!strncmp (properties.gcnArchName, ARCH, sizeof (ARCH) - 1))
{
std::cout << "Running on device #" << device_id << " "
<< properties.name << std::endl;
CHECK (hipSetDevice (device_id));
break;
}
}
if (device_id == device_count)
{
std::cerr << "Cannot find a suitable device to run the test."
<< std::endl;
exit (EXIT_FAILURE);
}
/* Load kernel binary. KERNEL_SO_NAME is the name of the .so file,
and is defined by the .exp file. Try loading it from
KERNEL_SO_PATH first (also defined by the .exp file), and
fallback to loading it from the current directory. The latter is
useful for standalone development, particularly when developing
non-GDB tools. */
hipModule_t module;
if (hipModuleLoad (&module, KERNEL_SO_PATH "/" KERNEL_SO_NAME) != hipSuccess)
CHECK (hipModuleLoad (&module, "./" KERNEL_SO_NAME));
hipFunction_t function;
CHECK (hipModuleGetFunction (&function, module, "AddrClassTest"));
int in_h[LANE_NUM], *in_d;
struct
{
int int_elem;
char char_elem;
int array_elem[LANE_NUM];
} out_h, *out_d;
CHECK (hipMalloc (&in_d, sizeof (in_h)));
CHECK (hipMalloc (&out_d, sizeof (out_h)));
for (size_t i = 0; i < LANE_NUM; ++i)
in_h[i] = i;
CHECK (hipMemcpy (in_d, &in_h, sizeof (in_h), hipMemcpyHostToDevice));
struct
{
decltype (in_d) in;
decltype (out_d) out;
} params = { in_d, out_d };
size_t params_size = sizeof (params);
void *config[]
= { HIP_LAUNCH_PARAM_BUFFER_POINTER, &params, HIP_LAUNCH_PARAM_BUFFER_SIZE,
&params_size, HIP_LAUNCH_PARAM_END };
CHECK (hipModuleLaunchKernel (function, 1, 1, 1, LANE_NUM, 1, 1, 0, 0,
nullptr, (void **) &config));
CHECK (hipMemcpy (&out_h, out_d, sizeof (out_h), hipMemcpyDeviceToHost));
CHECK (hipModuleUnload (module));
CHECK (hipFree (in_d));
CHECK (hipFree (out_d));
std::cout << "Results:" << std::endl;
for (size_t i = 0; i < LANE_NUM; ++i)
std::cout << "Lane " << i << ": " << out_h.array_elem[i] << std::endl;
return 0;
}